pub enum AlterKind {
AddColumns {
columns: Vec<AddColumn>,
},
DropColumns {
names: Vec<String>,
},
ModifyColumnTypes {
columns: Vec<ModifyColumnType>,
},
SetRegionOptions {
options: Vec<SetRegionOption>,
},
UnsetRegionOptions {
keys: Vec<UnsetRegionOption>,
},
SetIndexes {
options: Vec<SetIndexOption>,
},
UnsetIndexes {
options: Vec<UnsetIndexOption>,
},
DropDefaults {
names: Vec<String>,
},
SetDefaults {
columns: Vec<SetDefault>,
},
SyncColumns {
column_metadatas: Vec<ColumnMetadata>,
},
}Expand description
Kind of the alteration.
Variants
AddColumns
Add columns to the region.
DropColumns
Drop columns from the region, only fields are allowed to drop.
ModifyColumnTypes
Change columns datatype of the region. Field columns can change to any
Arrow-castable type; the time index column only supports widening its
timestamp unit (e.g. TimestampMillisecond -> TimestampMicrosecond),
which is lossless for values that fit the target unit’s i64 range.
Fields
columns: Vec<ModifyColumnType>Columns to change.
SetRegionOptions
Set region options.
Fields
options: Vec<SetRegionOption>UnsetRegionOptions
Unset region options.
Fields
keys: Vec<UnsetRegionOption>SetIndexes
Set index options.
Fields
options: Vec<SetIndexOption>UnsetIndexes
Unset index options.
Fields
options: Vec<UnsetIndexOption>DropDefaults
Drop column default value.
SetDefaults
Set column default value.
Fields
columns: Vec<SetDefault>Columns to change.
SyncColumns
Sync column metadatas.
Fields
column_metadatas: Vec<ColumnMetadata>Implementations
Sourceimpl AlterKind
impl AlterKind
Sourcepub fn validate(&self, metadata: &RegionMetadata) -> Result<()>
pub fn validate(&self, metadata: &RegionMetadata) -> Result<()>
Returns an error if the alter kind is invalid.
It allows adding column if not exists and dropping column if exists.
Sourcepub fn need_alter(&self, metadata: &RegionMetadata) -> bool
pub fn need_alter(&self, metadata: &RegionMetadata) -> bool
Returns true if we need to apply the alteration to the region.
Sourcefn validate_column_to_drop(name: &str, metadata: &RegionMetadata) -> Result<()>
fn validate_column_to_drop(name: &str, metadata: &RegionMetadata) -> Result<()>
Returns an error if the column to drop is invalid.
Sourcefn validate_column_alter_index_option(
column_name: &String,
metadata: &RegionMetadata,
is_fulltext: bool,
) -> Result<()>
fn validate_column_alter_index_option( column_name: &String, metadata: &RegionMetadata, is_fulltext: bool, ) -> Result<()>
Returns an error if the column’s alter index option is invalid.
Sourcefn validate_column_existence(
column_name: &String,
metadata: &RegionMetadata,
) -> Result<()>
fn validate_column_existence( column_name: &String, metadata: &RegionMetadata, ) -> Result<()>
Returns an error if the column isn’t exist.